==> haskell-mono-traversable-0.10.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-mono-traversable/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 0.10.1.1
id: mono-traversable-0.10.1.1-444d89c530a7a69af62384c66ba2d700
key: monot_EnmkMaVUxo4C44IB6nPhcq
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Monomorphic variants of the Functor, Foldable, and Traversable typeclasses. If you understand Haskell'\''s basic typeclasses, you understand mono-traversable. In addition to what you are used to, it adds on an IsSequence typeclass and has code for marking data structures as non-empty.
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
exposed-modules:
    Data.MonoTraversable Data.Containers Data.Sequences Data.NonNull
    Data.MinLen Data.ByteVector
hidden-modules: Data.GrowingAppend
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/mono-traversable-0.10.1.1
hs-libraries: HSmono-traversable-0.10.1.1-EnmkMaVUxo4C44IB6nPhcq
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    comonad-5-530ea4e1d08a0115920b946124e760ac
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
    dlist-instances-0.1-235f738d61a8b9c3c8305b99c3fa9cbe
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
    vector-instances-3.3.1-86a43cd9ce3eb5ed2f259da8231c727e
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-0.10.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-mono-traversable/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 0.10.1.1
id: mono-traversable-0.10.1.1-7ac62162d55f8d714083ba886bfb5efd
key: monot_2PxlfpjOgIc4vO19U1UddJ
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Monomorphic variants of the Functor, Foldable, and Traversable typeclasses. If you understand Haskell'\''s basic typeclasses, you understand mono-traversable. In addition to what you are used to, it adds on an IsSequence typeclass and has code for marking data structures as non-empty.
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
exposed-modules:
    Data.MonoTraversable Data.Containers Data.Sequences Data.NonNull
    Data.MinLen Data.ByteVector
hidden-modules: Data.GrowingAppend
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/mono-traversable-0.10.1.1
hs-libraries: HSmono-traversable-0.10.1.1-2PxlfpjOgIc4vO19U1UddJ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    comonad-5-a91321d086a2de4a04a44d60c347669e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
    dlist-instances-0.1-235f738d61a8b9c3c8305b99c3fa9cbe
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
    vector-instances-3.3.1-defbdcf4d1ffa7a1e6ebdf8243634c01
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
